Learn R Programming

GSIF (version 0.3-1)

landmask: 1-degree cell land mask for Global soil mapping purposes

Description

Land mask showing the 1-degree cells (about 19 thousand in total) in the geographical coordinates, and the productive soils mask (areas with a positive Leaf Area Index at least once in the period 2002--2011). The land mask is based on the http://www.ngdc.noaa.gov/mgg/shorelines/gshhs.html{Global Self-consistent, Hierarchical, High-resolution Shoreline Database} data (GSHHS 2.1), and the productive soils mask on the MODIS Leaf Area Index monthtly product (https://lpdaac.usgs.gov/lpdaac/products/modis_products_table/leaf_area_index_fraction_of_photosynthetically_active_radiation/8_day_l4_global_1km/mcd15a2{MOD15A2}).

Usage

data(landmask)

Arguments

References

  • Wessel, P., Smith, W.H.F., (1996)http://dx.doi.org/10.1029/96JB00104{A Global Self-consistent, Hierarchical, High-resolution Shoreline Database}. Journal of Geophysical Research, 101, 8741-8743.
  • Savtchenko, A., D. Ouzounov, S. Ahmad, J. Acker, G. Leptoukh, J. Koziana, and D. Nickless, (2004)http://dx.doi.org/10.1016/j.asr.2004.03.012{Terra and Aqua MODIS products available from NASA GES DAAC}. Advances in Space Research 34(4), 710-714.
  • Global Self-consistent, Hierarchical, High-resolution Shoreline Database (http://en.wikipedia.org/wiki/GSHHS)

See Also

rworldmap::rworldmapExamples, maps::map

Examples

Run this code
library(rgdal)
library(sp)

data(landmask)
gridded(landmask) <- ~x+y
proj4string(landmask) <- "+proj=longlat +datum=WGS84"
## plot maps:
require(maps)
country.m = map('world', plot=FALSE, fill=TRUE)
IDs <- sapply(strsplit(country.m$names, ":"), function(x) x[1])
require(maptools)
country <- as(map2SpatialPolygons(country.m, IDs=IDs), "SpatialLines")
spplot(landmask["mask"], col.regions="grey", sp.layout=list("sp.lines", country))
spplot(landmask["soilmask"], col.regions="grey", sp.layout=list("sp.lines", country))
## also available in the Robinson projection at 20 km grid:
data(landmask20km)
image(landmask20km)

Run the code above in your browser using DataLab